@@ -201,6 +201,7 @@ class MARBLE_EXPORT MarbleMap : public QObject
      * @param y      the y coordinate of the pixel
      * @param lon    the longitude angle is returned through this parameter
      * @param lat    the latitude angle is returned through this parameter
+     * @param unit   the angle units
      * @return @c true  if the pixel (x, y) is within the globe
      *         @c false if the pixel (x, y) is outside the globe, i.e. in space.
      */
@@ -414,7 +415,7 @@ class MARBLE_EXPORT MarbleMap : public QObject
 
     /**
      * @brief Removes a texture sublayer
-     * @param Key that was returned from corresponding addTextureLayer
+     * @param key a key that was returned from corresponding addTextureLayer
      */
     void removeTextureLayer(const QString &key);
 
@@ -502,6 +503,7 @@ class MARBLE_EXPORT MarbleMap : public QObject
 
     /**
      * @brief  Sets the value of a map theme property
+     * @param  name   name of the property
      * @param  value  value of the property (usually: visibility)
      * 
      * Later on we might add a "setPropertyType and a QVariant
@@ -535,7 +537,7 @@ class MARBLE_EXPORT MarbleMap : public QObject
 
     /**
      * @brief  Set whether the night shadow is visible.
-     * @param  visibile visibility of shadow
+     * @param  visible visibility of shadow
      */
     void setShowSunShading( bool visible );
 
@@ -547,7 +549,7 @@ class MARBLE_EXPORT MarbleMap : public QObject
 
     /**
      * @brief  Set the globe locked to the sub solar point
-     * @param  vsible if globe is locked to the sub solar point
+     * @param  visible if globe is locked to the sub solar point
      */
     void setLockToSubSolarPoint( bool visible );
 
@@ -702,7 +704,7 @@ class MARBLE_EXPORT MarbleMap : public QObject
     void clearVolatileTileCache();
     /**
      * @brief  Set the limit of the volatile (in RAM) tile cache.
-     * @param  bytes The limit in kilobytes.
+     * @param  kiloBytes The limit in kilobytes.
      */
     void setVolatileTileCacheLimit( quint64 kiloBytes );
 
@@ -734,7 +736,7 @@ class MARBLE_EXPORT MarbleMap : public QObject
 
     void radiusChanged( int radius );
 
-    void mouseMoveGeoPosition( const QString& );
+    void mouseMoveGeoPosition( const QString& geoPositionString);
 
     void mouseClickGeoPosition( qreal lon, qreal lat, GeoDataCoordinates::Unit );
 
